@@ -47,6 +47,7 @@
 
 #include <pwiz/data/msdata/MSDataFile.hpp>
 #include <pwiz/data/msdata/DefaultReaderList.hpp>
+#include <pwiz/utility/misc/BinaryData.hpp>
 
 using namespace pwiz::msdata;
 
@@ -529,7 +530,7 @@ Trace::initialize(const QByteArray *keyByteArray,
   deleteDataPoints();
 
   // Because pwiz provides the mass spectral data in the form of
-  // std::vector<double> data, we need to encode these data before we
+  // BinaryData data, we need to encode these data before we
   // can inject them to the database.
 
   pwiz::msdata::BinaryDataEncoder::Config config;
@@ -550,7 +551,7 @@ Trace::initialize(const QByteArray *keyByteArray,
 
   // Start by crunching the key data.
 
-  std::vector<double> keyStdVector;
+	pwiz::util::BinaryData<double> keyStdVector;
 
   std::string keyString = keyByteArray->toStdString();
 
@@ -566,7 +567,7 @@ Trace::initialize(const QByteArray *keyByteArray,
 
   // And now do the same for the i data.
 
-  std::vector<double> valStdVector;
+	pwiz::util::BinaryData<double> valStdVector;
 
   std::string valString = valByteArray->toStdString();
 
