@@ -97,7 +97,7 @@ namespace msXpSmineXpert
 	 *
 	 * - savGolParams: <SavGolParams> object holding the configuration of a
 	 *   Savitzky-Golay filtering process.</comment>
-	*/
+	 */
 
 
 	MzIntegrationParamsJs::MzIntegrationParamsJs(QScriptEngine *engine)
@@ -164,7 +164,14 @@ namespace msXpSmineXpert
 	/*/js/
 	 * MzIntegrationParams()
 	 *
-	 * Constructor of a MzIntegrationParams instance
+	 * Construct a MzIntegrationParams instance with default values.
+	 *
+	 * Ex:
+	 *
+	 * var mzip1 = new MzIntegrationParams();
+	 *
+	 * mzip1.binningType; // --> 0
+	 * mzip1.binningTypeString; // --> NONE
 	 */
 	QScriptValue
 		MzIntegrationParamsJs::newInstance()
@@ -179,13 +186,24 @@ namespace msXpSmineXpert
 	 * MzIntegrationParams(binningType, binSize, binSizeType,
 	 * applyMzShift, removeZeroValDataPoints)
 	 *
-	 * Constructor of a MzIntegrationParams instance
+	 * Construct a MzIntegrationParams instance using specified values.
 	 *
 	 * binningType: <Number> type of the binning (refer to msXpS::BinningType for details)
 	 * binSize: <Number> size of the bins
 	 * binSizeType: <Number> type of the bin size (refer to msXpS::MassToleranceType for details)
 	 * applyMzShift: <Boolean> tells if the m/z shift correction should be applied
 	 * removeZeroValDataPoints: <Boolean> tells if the 0-val m/z data points should be removed
+	 *
+	 * Ex:
+	 *
+	 * var mzip1 = new MzIntegrationParams(1, 0.0055, 2, false, true);
+	 *
+	 * mzip1.binningTypeString; // --> DATA_BASED
+	 * mzip1.binSize; // --> 0.0055
+	 * mzip1.binSizeType; // --> 2
+	 * mzip1.binSizeTypeString; // --> MZ
+	 * mzip1.applyMzShift; // --> false
+	 * mzip1.removeZeroValDataPoints; // --> true
 	 */
 	QScriptValue
 		MzIntegrationParamsJs::newInstance(msXpS::BinningType binningType,
@@ -202,7 +220,28 @@ namespace msXpSmineXpert
 	/*/js/
 	 *	MzIntegrationParams(mzIntegrationParams)
 	 *
-	 * Constructor of a MzIntegrationParams object
+	 * Construct a MzIntegrationParams object using a <MzIntegrationParams>
+	 * template object.
+	 *
+	 * Ex:
+	 *
+	 * var mzip1 = new MzIntegrationParams(1, 0.0055, 2, false, true);
+	 *
+	 * mzip1.binningTypeString; // --> DATA_BASED
+	 * mzip1.binSize; // --> 0.0055
+	 * mzip1.binSizeType; // --> 2
+	 * mzip1.binSizeTypeString; // --> MZ
+	 * mzip1.applyMzShift; // --> false
+	 * mzip1.removeZeroValDataPoints; // --> true
+	 *
+	 * var mzip2 = new MzIntegrationParams(mzip1);
+	 *
+	 * mzip2.binningTypeString; // --> DATA_BASED
+	 * mzip2.binSize; // --> 0.0055
+	 * mzip2.binSizeType; // --> 2
+	 * mzip2.binSizeTypeString; // --> MZ
+	 * mzip2.applyMzShift; // --> false
+	 * mzip2.removeZeroValDataPoints; // --> true
 	 *
 	 * mzIntegrationParams: <MzIntegrationParams> to be used to initialize this object
 	 */
@@ -217,7 +256,7 @@ namespace msXpSmineXpert
 			// associated to the MzIntegrationParamsJs class (that is, this).
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "Right before returning QScriptValue as newObject(this, data);";
+			//<< "Right before returning QScriptValue as newObject(this, data);";
 
 			return engine()->newObject(this, data);
 		}
@@ -226,7 +265,18 @@ namespace msXpSmineXpert
 	/*/js/
 	 * MzIntegrationParams(savGolParams)
 	 *
-	 * Constructor of a MzIntegrationParams object
+	 * Construct a MzIntegrationParams object using a SavGolParams template
+	 * object.
+	 *
+	 * Ex:
+	 *
+	 * var sgp1 = new SavGolParams(10, 10, 6, 0, true);
+	 * var mzip1 = new MzIntegrationParams(sgp1);
+	 *
+	 * mzip1.savGolParams.nL; // --> 10
+	 * mzip1.savGolParams.nR; // --> 10
+	 * mzip1.savGolParams.m; // --> 6
+	 * mzip1.savGolParams.lD; // --> 0
 	 *
 	 * savGolParams: <SavGolParams> object to be used to initialize this object's SavGolParams
 	 */
@@ -253,7 +303,7 @@ namespace msXpSmineXpert
 				const QScriptString &name, QueryFlags flags, uint *id)
 		{
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "with name:" << name;
+			//<< "with name:" << name;
 
 			MzIntegrationParams *mziParams = qscriptvalue_cast<MzIntegrationParams *>(object.data());
 
@@ -269,6 +319,10 @@ namespace msXpSmineXpert
 			{
 				return flags;
 			}
+			if(name == binningTypeString)
+			{
+				return flags;
+			}
 			else if(name == binSize)
 			{
 				return flags;
@@ -321,19 +375,39 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzintegrationParams>.binningType
 				 *
+				 * Return the binningType property of the object as a <Number>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binningType; // --> 0
+				 *
 				 * Return the binning type property as a <Number>.
 				 */
 
 				return QScriptValue(mziParams->m_binningType);
 			}
-			if(name == binningTypeString)
+			else if(name == binningTypeString)
 			{
 				/*/js/
 				 * <MzintegrationParams>.binningTypeString
 				 *
+				 * Return the binningType property of the object as a <String>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binningTypeString; // --> NONE
+				 *
 				 * Return the binning type property as a <String>.
 				 */
 
+				QString binningTypeString = msXpS::binningTypeMap.value(mziParams->m_binningType);
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "string:" << binningTypeString;
+
 				return msXpS::binningTypeMap.value(mziParams->m_binningType);
 			}
 			else if(name == binSize)
@@ -341,6 +415,14 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzIntegrationParams>.binSize
 				 *
+				 * Return the bin size property of the object.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binSize; // --> NaN (uninitialized value)
+				 *
 				 * Return the bin size <Number> property (size of the bins in the mass
 				 * spectrum).
 				 */
@@ -351,6 +433,14 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzintegrationParams>.binSizeType
 				 *
+				 * Return the binSizeType property of the object as a <Number>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binSizeType; // --> 0
+				 *
 				 * Return the bin size type property as a <Number>.
 				 */
 
@@ -361,6 +451,14 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzintegrationParams>.binSizeTypeString
 				 *
+				 * Return the binSizeType property of the object as a <String>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binSizeTypeString; // --> NONE
+				 *
 				 * Return the bin size type property as a <String>.
 				 */
 
@@ -371,6 +469,14 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzIntegrationParams>.applyMzShift
 				 *
+				 * Ex:
+				 *
+				 *  var mzip1 = new MzIntegrationParams();
+				 *  
+				 *  mzip1.applyMzShift; // --> false
+				 *  mzip1.applyMzShift = true;
+				 *  mzip1.applyMzShift; // --> true
+				 *
 				 * Return the <Boolean> value telling if the m/z shift should be
 				 * applied.
 				 */
@@ -382,6 +488,12 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzIntegrationParams>.removeZeroValDataPoints
 				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.applyMzShift; // --> false
+				 *
 				 * Return the <Boolean> value telling if the <DataPoint> objects having
 				 * m/z keys of a 0-intensity value should be removed from the
 				 * <MassSpectrum> object.
@@ -393,6 +505,12 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzIntegrationParams>.applySavGolFilter
 				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.applySavGolFilter // --> false
+				 *
 				 * Return the <Boolean> value telling if the Savitzky-Golay filter
 				 * should be applied to the <MassSpectrum> object.
 				 */
@@ -404,6 +522,18 @@ namespace msXpSmineXpert
 				/*/js/
 				 * <MzIntegrationParams>.savGolParams
 				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * var sgp1 = mzip1.savGolParams;
+				 *
+				 * sgp1.nL; // --> 15
+				 * sgp1.nR; // --> 15
+				 * sgp1.m; // --> 4
+				 * sgp1.lD; // --> 0
+				 * sgp1.convolveWithNr;	 // --> false
+				 *
 				 * Return the <SavGolParams> object from this <MzIntegrationParams>
 				 * object.
 				 */
@@ -424,30 +554,168 @@ namespace msXpSmineXpert
 
 			if(name == binningType)
 			{
-				mziParams->m_binningType = qscriptvalue_cast<msXpS::BinningType>(value);
+				/*js/
+				 * MzIntegrations.binningType = <Number>
+				 *
+				 * Set the binning type as a <Number>.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binningType; // --> 0
+				 * mzip1.binningType = 2;
+				 * mzip1.binningType; // --> 2
+				 */
+
+				mziParams->m_binningType = static_cast<msXpS::BinningType>(qscriptvalue_cast<int>(value));
+			}
+			else if(name == binningTypeString)
+			{
+				/*js/
+				 * MzIntegrations.binningTypeString = <Number>
+				 *
+				 * Set the binning type as a <String>.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binningTypeString = "ARBITRARY";
+				 * mzip1.binningTypeString; // --> ARBITRARY
+				 * mzip1.binningType; // --> 2
+				 */
+
+				int binningType = msXpS::binningTypeMap.key(qscriptvalue_cast<QString>(value));
+				mziParams->m_binningType = static_cast<msXpS::BinningType>(binningType);
 			}
 			else if(name == binSize)
 			{
+				/*/js/
+				 * MzIntegrationParams.binSize = <Number>
+				 *
+				 * Set the bin size.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 * mzip1.binSize; // --> NaN (uninitialized)
+				 * mzip1.binSize = 0.0055;
+				 * mzip1.binSize; // --> 0.0055
+				 */
+
 				mziParams->m_binSize = qscriptvalue_cast<double>(value);
 			}
 			else if(name == binSizeType)
 			{
-				mziParams->m_binSizeType = qscriptvalue_cast<msXpS::MassToleranceType>(value);
+				/*/js/
+				 * MzIntegrationParams.binSizeType = <Number>
+				 *
+				 * Set the bin size type as a <Number>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.binSizeType; // --> 0
+				 * mzip1.binSizeTypeString; // --> NONE
+				 * mzip1.binSizeType=1;
+				 * mzip1.binSizeType; // --> 1
+				 * mzip1.binSizeTypeString; // --> PPM
+				 */
+				mziParams->m_binSizeType = static_cast<msXpS::MassToleranceType>(qscriptvalue_cast<int>(value));
+			}
+			else if(name == binSizeTypeString)
+			{
+				/*/js/
+				 * MzIntegrationParams.binSizeTypeString = <String>
+				 *
+				 * Set the bin size type as a <String>
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 * mzip1.binSizeTypeString; // --> NONE
+				 * mzip1.binSizeTypeString = "RES";
+				 * mzip1.binSizeTypeString; // --> RES
+				 * mzip1.binSizeType; // --> 4
+				 */
+				int binSizeType = msXpS::massToleranceTypeMap.key(qscriptvalue_cast<QString>(value));
+				mziParams->m_binSizeType = static_cast<msXpS::MassToleranceType>(binSizeType);
 			}
 			else if(name == applyMzShift)
 			{
+				/*/js/
+				 * MzIntegrationParams.applyMzShift = <Boolean>
+				 *
+				 * Tell if the m/z shift between spectra must be applied
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.applyMzShift; // --> false
+				 * mzip1.applyMzShift = true;
+				 * mzip1.applyMzShift; // --> true
+				 */
 				mziParams->m_applyMzShift= qscriptvalue_cast<bool>(value);
 			}
 			else if(name == removeZeroValDataPoints)
 			{
+				/*/js/
+				 * MzIntegrationParams.removeZeroValDataPoints = <Boolean>
+				 *
+				 * Tell if the DataPoint objects having a value of 0 need to be removed
+				 * from the spectrum.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.applyMzShift; // --> false
+				 * mzip1.applyMzShift = true;
+				 * mzip1.applyMzShift; // --> true
+				 */
+
 				mziParams->m_removeZeroValDataPoints = qscriptvalue_cast<bool>(value);
 			}
 			else if(name == applySavGolFilter)
 			{
+				/*/js/
+				 * MzIntegrationParams.removeZeroValDataPoints = <Boolean>
+				 *
+				 * Tell if the Savitzky-Golay filter needs to be applied to the
+				 * combination spectrum.
+				 *
+				 * Ex:
+				 *
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.applySavGolFilter; // --> false
+				 * mzip1.applySavGolFilter = true;
+				 * mzip1.applySavGolFilter; // --> true;
+				 */
 				mziParams->m_applySavGolFilter = qscriptvalue_cast<bool>(value);
 			}
 			else if(name == savGolParams)
 			{
+				/*/js/
+				 * MzIntegrationParams.savGolParams = <SavGolParams>
+				 *
+				 * Initialize the member <SavGolParams> object using the parameter as
+				 * template.
+				 *
+				 * Ex:
+				 *
+				 * var sgp1 = new SavGolParams(10, 10, 6, 0, true);
+				 * var mzip1 = new MzIntegrationParams();
+				 *
+				 * mzip1.savGolParams.nL; // --> 15
+				 * mzip1.savGolParams.nR; // --> 15
+				 * mzip1.savGolParams = sgp1;
+				 * mzip1.savGolParams.nL; // --> 10
+				 * mzip1.savGolParams.nR; // --> 10
+				 */
 				mziParams->m_savGolParams = qscriptvalue_cast<SavGolParams>(value);
 			}
 
@@ -468,7 +736,7 @@ namespace msXpSmineXpert
 				return QScriptValue();
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "Found the MzIntegrationParamsJs class.";
+			//<< "Found the MzIntegrationParamsJs class.";
 
 			int argCount = ctx->argumentCount();
 
@@ -481,12 +749,12 @@ namespace msXpSmineXpert
 				if(variant.isValid())
 				{
 					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-						//<< "Variant user type:" << variant.userType();
+					//<< "Variant user type:" << variant.userType();
 
 					if(variant.userType() == QMetaType::type("msXpSmineXpert::MzIntegrationParams"))
 					{
 						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
-							//<< "The argument passed to the constructor is a MzIntegrationParams.";
+						//<< "The argument passed to the constructor is a MzIntegrationParams.";
 
 						return cls->newInstance(qscriptvalue_cast<MzIntegrationParams>(arg));
 					}
@@ -505,7 +773,7 @@ namespace msXpSmineXpert
 					}
 
 					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-						//<< "QVariant user type: " << variant.userType();
+					//<< "QVariant user type: " << variant.userType();
 
 					QScriptValue nLValue = arg.property("nL", QScriptValue::ResolveLocal);
 
@@ -517,7 +785,7 @@ namespace msXpSmineXpert
 						SavGolParams params = qscriptvalue_cast<SavGolParams>(arg);
 
 						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-							//<< "We are constructing from SavGolParams.";
+						//<< "We are constructing from SavGolParams.";
 
 						return cls->newInstance(params);
 					}
